@@ -6,6 +6,7 @@ import (
 	"runtime"
 	"strings"
 	"testing"
+	"time"
 )
 
 const (
@@ -175,6 +176,33 @@ func TestReadConfigWithWrongPath(t *testing.T) {
 	}
 }
 
+func TestKillDelay(t *testing.T) {
+	config := Config{
+		Build: cfgBuild{
+			KillDelay: 1000,
+		},
+	}
+	if config.killDelay() != (1000 * time.Millisecond) {
+		t.Fatal("expect KillDelay 1000 to be interpreted as 1000 milliseconds, got ", config.killDelay())
+	}
+	config.Build.KillDelay = 1
+	if config.killDelay() != (1 * time.Millisecond) {
+		t.Fatal("expect KillDelay 1 to be interpreted as 1 millisecond, got ", config.killDelay())
+	}
+	config.Build.KillDelay = 1_000_000
+	if config.killDelay() != (1 * time.Millisecond) {
+		t.Fatal("expect KillDelay 1_000_000 to be interpreted as 1 millisecond, got ", config.killDelay())
+	}
+	config.Build.KillDelay = 100_000_000
+	if config.killDelay() != (100 * time.Millisecond) {
+		t.Fatal("expect KillDelay 100_000_000 to be interpreted as 100 milliseconds, got ", config.killDelay())
+	}
+	config.Build.KillDelay = 0
+	if config.killDelay() != 0 {
+		t.Fatal("expect KillDelay 0 to be interpreted as 0, got ", config.killDelay())
+	}
+}
+
 func contains(sl []string, target string) bool {
 	for _, c := range sl {
 		if c == target {
